.TH  ALSCRIPT

.SH NAME
ALSCRIPT - Sequence alignment to PostScript

.SH SYNOPSIS
alscript [cmdfile]

.SH DESCRIPTION


ALSCRIPT takes a multiple sequence alignment in AMPS (Barton &
Sternberg, 1987, Barton, 1990) block-file format and a set of
formatting commands and produces a PostScript file that may be printed
on a PostScript laser printer, or viewed using a PostScript previewer
(e.g. Sun Microsystem's PageView program).  CLUSTAL and GCG format
multiple alignment files may also be used (see below).  ALSCRIPT is NOT a
multiple sequence alignment program, nor is it an alignment editor.

Given a block-file and pointsize (character width/height), ALSCRIPT
calculates how many  residues can be fitted across the page, and how
many sequences will fit down the page, it then  prints the  alignment at
the chosen pointsize on as many pages as are needed.  Running ALSCRIPT  with
a smaller or larger pointsize will automatically re-scale the alignment
to fit on fewer or more pages as appropriate.  The actual page
dimensions may be re-set to any value, so if you  have access to an A3
PostScript printer, or typesetting machine, alignments can readily be
scaled to maximise the available space.

Each output page has three basic regions.  The left hand edge contains
identifier codes for each sequence.  The main part of the page holds the
alignment, and the top part, the position numbers and tick marks.  ALSCRIPT
commands make use of a character coordinate system for font  changes,
and other formatting commands. Thus, any residue  in the alignment may
be referred to by its sequence  position number (x-axis) and sequence
number  (y-axis), similarly, ranges of residue positions, or sequences
may also be defined in the  character coordinate system.

The basic ALSCRIPT commands allow the following functionality:

Fonts:  Any PostScript font at any size may be defined and used on
individual residues,  regions or identifier codes.

Boxing: Simple rectangular boxes may be drawn around any part of the
alignment.  Particular  residue types may be selected and automatically
"surrounded" by lines.  For example, if the  characters 'G' and 'P' are
selected, then lines will not be drawn between G and P characters,  but
only where G and P border with other characters.

Shading:  Grey shading of any level from black to white may be applied
to any region of the  alignment, either as a rectangular region, or as
residue specific shading.  e.g. "shade all Cys residues between
positions 6 and 30" 

Text:  Specific text strings may be added to the alignment at any
position and in any font or font size.

Lines: Horizontal or vertical lines may be drawn to the left, right, top
or bottom of any  residue position or group of positions.

Colour:  Characters or character backgrounds may be independently
coloured. 

The example block file "example1.blc" and command file "example1.com"
illustrate most of these commands in action.

Although written with the aim of producing figures for journal
submission, ALSCRIPT may be used as a tool for interpreting multiple
sequence alignments.  For example, the boxing, shading and font changing
facilities can be applied to highlight amino acids of a particular type
and thus draw  attention  to clusters of positive or negative charge,
hydrophobics, etc.  


.SH New Features in Version 1.4.4

This version introduces the MASK family of commands which allows
boxing, shading etc to be applied according to the frequency of
occurence of the character types at each position in the alignment.
For example, it is possible to box positions where one character is
seen in more than N of the sequences.  It is also possible to
box/shade etc the most frequently occurring character at each
position.  Commands exist to select which characters will be used in
the calculation of frequencies and which will be excluded, thus boxing
can be based upon two or more character types at a position.  MASK
commands also exist to show residues identical to one sequence in the
set.  See the section on MASK below for details.

NOTE: Although boxing according to the frequency of amino acids seen
at a position is a popular method of representation it is not usually
the most informative.  An analysis that takes into account the
physico-chemical properties of the amino acids and also relates the
amino acid similarities to the overall similarity between the
sequences is more helpful in identifying functionally important
residues.  The AMAS program (Livingstone and Barton, 1993) applies a
flexible hierarchical set-based approach to this problem.

.SH New Features in Version 1.4.5 - Program alsnum

Version 1.4.5 includes the program "alsnum".  This is a temporary solution to 
the residue numbering problem.  Ultimately, these functions will be included
as alscript commands.

alsnum creates a set of TEXT commands that can be incorporated into an 
alscript command file to place sequential numbers at any position in the
alignment.  The numbers ignore gaps, so the numbering will correspond to 
the specific sequence position rather than the alignment.

To use the program:

1.  Decide where you want the numbers to be placed.  For example, you might
want the numbers above the third sequence in the alignment.  If so, make
an extra sequence space above the third sequence using the ADD_SEQ command.

2.  Decide what is the number of the first residue of the sequence to be 
numbered.   This will not always be 1 since you may be aligning fragments
or domains.

3.  Decide the numbering interval (e.g. every 10th amino acid).

4.  Run the program.  

For example, if you want to add numbers according to sequence 37 of a
block file (junk.blc), calling the first residue of the sequence 12,
and with an interval of 5, and the numbers are to be placed at the
location of sequence 3 in the alignment.  Type:

alsnum 37 12 5 3 < junk.blc > junk.text

5.  Add the resulting TEXT commands from junk.text to your alscript 
command file.


.SH Running ALSCRIPT

I recommend you read through this section, then scan the commands in
APPENDIX 1 to get a feel for what ALSCRIPT can do.

See APPENDIX 7 for alternative methods of invoking ALSCRIPT.  In this
section, the interactive method is described.  The QUICK START method
shown in APPENDIX 7 is useful to quickly format a sequence alignment using
standard pointsize and shading.

ALSCRIPT is designed to work with AMPS block file format multiple
alignments.  If you have a multiple alignment generated by CLUSTAL V
or the GCG package, then it must be translated to AMPS block file
format.

To translate a GCG .MSF file: Type:  msf2blc.
To translate a CLUSTAL PIR format file, or any PIR format file:  clus2blc.

Both programs prompt for the name of an input file, and an output
block file name.   A good convention to follow is to name all blockfiles
with the extension ".blc".

To run ALSCRIPT simply type:

alscript

you will then be prompted for the name of the ALSCRIPT command file.
Having typed the filename, the commands will be executed as you have
specified.

A Simple Command File (example.com)

The file example.blc contains a small multiple sequence alignment.
The following ALSCRIPT command file will convert this into a
PostScript alignment file in 12 point Helvetica.

#Comments in ALSCRIPT command files start with a #
#
#Commands are free format - separated by blank, tab or comma characters
#
BLOCK_FILE 	example.blc 		#define the block file to format
OUTPUT_FILE 	example.ps		#where to put the result
LANDSCAPE				#landscape paper orientation
POINTSIZE 12				#12 point default pointsize
DEFINE_FONT 0 Helvetica DEFAULT		#set font 0 to be Helvetica
SETUP					#Tell the program to get on with it.

Now try changing the POINTSIZE value to 5 ALSCRIPT will re-format the
alignment to make best use of the available paper.

These are all STEP 1 commands - they refer to overall layout, and system
settings - for example, the paper size or maximum sequence length. 
Other  commonly used STEP 1 commands are IDENT_WIDTH which reserves more
or less  width for the sequence identifier codes, NUMBER_SEQS which adds
a  number to each sequence and LINE_WIDTH_FACTOR which allows the
thickness of all boxing lines to be adjusted.  See  APPENDIX 1 for
details of these and other all STEP 1 commands.

The simple example outlined above can be modified with a variety of 
STEP 2 commands.

for example file example2.com:

# FILE example2.com
#
#Commands are free format - separated by blank, tab or comma characters
#
BLOCK_FILE 	example.blc 		#define the block file to format
OUTPUT_FILE 	example2.ps		#where to put the result
LANDSCAPE				#landscape paper orientation
POINTSIZE 12				#12 point default pointsize
DEFINE_FONT 0 Helvetica DEFAULT		#set font 0 to be Helvetica
DEFINE_FONT 1 Helvetica REL 0.5         #set font 1 to be half sized Helvetica
DEFINE_FONT 3 Helvetica-Bold DEFAULT    #set font 3 to be Bold Helvetica
DEFINE_FONT 4 Times-BoldItalic DEFAULT  #font 4 is Times-BoldItalic
NUMBER_SEQS				#Number the sequences at left hand side
SETUP					#Tell the program to get on with it.
#
#step 2 commands come after the SETUP command 
#
#Here are some examples...
#
SURROUND_CHARS GP ALL		#draw lines around all G and P
SHADE_CHARS ILVW ALL 0.6	#shade all I L V and W with value 0.6
BOX_REGION 1 1 2 20 0.8		#rectangular box from positions 1 to 2 of sequences 1 to 20
FONT_CHARS C ALL 3              #Use font 3 (BOLD Helvetica) for C characters
ID_FONT ALL 1                   #set identifiers in font 1

There are many possible ways of combining these commands and the
others shown in APPENDIX 1.  In general, if you apply multiple
commands to the same residue, the effect of the last applied command
persists where there would otherwise be a conflict.  Thus the
intersection of two overlapping SHADed regions would be shaded
according to the second SHADE command, not some mixture of the two.
Similarly for FONT commands.  BOX and SURROUND commands behave in the
opposite sense, all BOXing and SURROUNDing persists regardless of how
many commands you issue.  This makes it possible for example, to
SURROUND two different sets of residues as follows:

SURROUND_CHARS DE ALL
SURROUND_CHARS DEHKR ALL

This would result in D and E characters being partitioned from the rest as well
as D E H K R characters (see Example output).

More complex effects - Text Lines, and Masks

Text,  lines and masking are meant to be used to annotate the multiple 
alignment.  The TEXT command allows any piece of text to be located
anywhere on the alignment.  Clearly, however it makes little sense to 
superimpose the text over the alignment though this can be done!  Accordingly, 
you must first make a space to put the text in.  Usually, this will be a 
few lines below the multiple sequence alignment, but you may want to 
add text at the top, or somewhere in between two sequences.  You can make
space in two ways.  Either by editing the block-file to introduce "dummy"
sequences at the locations you want, or by making use of the ADD_SEQ
command.

The ADD_SEQ command has two arguments, the sequence after which you want
further sequences to be added, and how many blank sequences you need.
Thus, we can reserve space for 5 lines of text underneath a 10 sequence 
multiple alignment with the following command.

ADD_SEQ 10 5

we can then put text below the alignment at the 20th residue.

TEXT 20 13 "Active Site His"
or any other position.

Similarly, we could draw a vertical line to point out which residue we mean

LINE LEFT 20 13 11

And change the font of the text to number 7 (whatever that has been set to):

FONT_RESIDUE 20 13 7

You can have multiple ADD_SEQ commands, but they must occur in sequence order.
Thus 
ADD_SEQ 0 5
ADD_SEQ 5 12
is legal.
But
ADD_SEQ 5 12
ADD_SEQ 0 5 
Is NOT!!   NO CHECKING IS performed by the program for this error - so beware!

Note that add_seq commands refer to the actual sequence number as implied by the
block file, not the number after applying the add_seq command.  Thus, for a four
sequence block file, if you want to add space for three sequences before sequence 1
and two sequences after sequence 3, the commands would be:
ADD_SEQ 0 3
ADD_SEQ 3 2

Text added with the TEXT command will not be split across page breaks,
so you may in some circumstances need to fiddle a little with the
location/pointsize for the text to get the desired result.

Masking is a technique for drawing irregular shaped outlines, or
shaded regions - this should not be confused with the MASK family of commands
described below.  For example a histogram can be added to the bottom of
an alignment by first defining some dummy sequences in the block-file
that have letters building up the shape of the histogram, then using
the SURROUND_CHARS or SHADE_CHARS commands together with the SUB_CHARS
command to produce the desired effect.  An example of this operation
being used to show frequencies of secondary structure predictions is
shown in example1.com and in the Protein Engineering paper.

.SH Using Colour

Version 1.4 includes commands to allow the independent colouring of
characters, or their backgrounds.  Colours are defined in a similar
manner to fonts using the DEFINE_COLOUR command (American spelling also
allowed).  For example:

DEFINE_COLOUR 7 1 0 0

defines colour number 7 to be red - see APPENDIX I for full details of
this command.  Colours 99 and 100 are pre-defined to white and black.
ALSCRIPT assumes the paper colour is white.

The command to colour the text of a character or text string is:

CCOL_CHARS

the command to colour the background of a character is

SCOL_CHARS

both have similar syntax to the FONT_CHARS command.

COLOUR_REGION  and COLOUR_RES have similar syntax to SHADE_REGION and
SHADE_RES.

An example command file that uses colour is shown in example3.com.

.SH The MASK command family

The idea behind the MASK command is to build up a set of character
positions that will subsequently be boxed, shaded, set in a particular
font, etc.  For example, lets say we want to box the most frequently
occuring character at each position in an alignment.

The command

mask SETUP 

tells ALSCRIPT to prepare a mask.

mask FRE ALL 

specifies that the most frequently occuring character at each position
in the alignment will be masked.  This command can be restricted to a
region of the alignment using: mask FRE sx sy ex ey, where sx etc
define the region in the same way as for font_region and other commands.

mask BOX ALL

Tells ALSCRIPT to create the boxing lines that will separate the masked
characters from non-masked characters - this command may also be
restricted to a region of the alignment.

The mask can be reset for re-use using the command:

mask RESET

Two further commands define which characters can be used when
calculating the mask.  This allows gap-characters, or other amino acids
to be excluded from the calculation to avoid unwanted boxing.

mask LEGAL "AVLI"

defines the AVL and I as the only characters that will be used when
calculating the mask.

mask ILLEGAL ".-_"

defines .- and _ as characters that will not be used when calculating
the mask.  NOTE:  the blank character " " cannot be defined in this way.
To avoid boxing " " characters substitute blanks for something else
(using SUB_CHARS), calculate the mask, then substitute back.

.SH Summary of mask commands

mask SETUP             
# Prepares for masking

mask LEGAL <qstring>   
# defines characters to include in ID or FRE calcs - optional.

mask ILLEGAL <qstring> 
# defines characters to exclude in ID or FRE calcs - optional.

mask ID ALL N
# Calculates a mask that flags the character that occurs at least N
times at a position.  The word ALL can be substituted by four numbers
that define a region of the alignment.

mask FRE ALL
# calculates a mask that flags the most frequently occuring amino acid
at each position.  ALL may be replaced by four numbers defining a region
of the alignment.

Multiple mask FRE or mask ID commands may be applied, using different
LEGAL and ILLEGAL character definitions.  In this way more complex
effects can be built up.

The mask command also allows characters that are identical to one
sequence to be masked.

mask AGREE ALL N

will mask all positions that are identical to the Nth sequence.  Thus,
for sequences that are very similar to a newly sequenced sequence, all
characters identical to the new sequence can be boxed or shaded, or set
in a different font or colour etc...

mask NOT ALL

allows the mask to be inverted.  Thus, all positions that are NOT in the
mask now form the mask.  So, having done a mask AGREE, a mask NOT will
allow the positions that are not identical to the selected sequence to
be highlighted or substituted.

mask SUB ALL <char>

substitutes all characters in the mask with  the character <char>.

mask REGION ALL
applies a mask to all residues  in  the defined region.

The following effects can now be applied to the masked characters:

mask BOX ALL 
# boxes the masked residues - ie surrounds them by lines.
mask SHADE ALL <grey>
# shades the masked residues by grey value.
mask FONT ALL <fontnum>
# Uses font fontnum to output the masked residues.
mask INVERSE ALL 
# Inverts the masked characters - ie outputs them in white.
mask CCOL ALL <colnum>
# outputs the masked characters in the defined colour.
mask SCOL ALL <colnum>
# outputs the backgrounds of the masked characters in the defined
colour.

In all commands, the word ALL can be replaced by four numbers defining
the region to which the command is applied.

mask RESET
# resets the entire mask for re-use




.SH APPENDIX 1:  ALSCRIPT Command Summary.

WARNING:  Very little error checking is performed on command input.  If
you give the wrong number of arguments to a command, then unexpected
things may happen, or the program will crash very inelegantly.  I hope
to fix this in version 2.0 of the program, in the meantime, make sure
you give the correct number of arguments to each command.

All commands up to the first space character may be entered in UPPER
or lower case or MiXEd case.  Qualifiers for commands (e.g. REL) must
be written in UPPER case.

Command Reference:

<int>  = enter an integer  (e.g. 240)
<float> = enter a floating point number (e.g. 0.45)
<string> = enter a string (e.g.  ARNDql)
<qstring> = enter a quoted string (e.g. "Active Site")
<char>    = enter a single character.

.SH STEP 1 COMMANDS:

These all refer to either system settings - e.g. the maximum allowed
sequence length, or to  general page layout features.  e.g. the longest
and shortest side of the paper on which you are plotting.

REQUIRED STEP 1 COMMANDS:

BLOCK_FILE <string>

Gives the name of the file that contains the multiple sequence alignment
to be formatted.  File names should be fully qualified i.e. not 
relative to the current directory.  If no block file command is given, 
ALSCRIPT will expect to read the block file from standard input.

OUTPUT_FILE <string>

Defines the output file name.  This command should be near the beginning of
the command list.
e.g. OUTPUT_FILE  Figure1.ps

You MUST define an output file unless the -p option (see APPENDIX &) is used.

DEFINE_FONT <int> <string> (<int>/DEFAULT)/(REL <float>)

Defines a font to use later:
e.g.
DEFINE_FONT 0 Helvetica 10
DEFINE_FONT 2 Times-Roman 2

defines font number 0 to be 10 point Helvetica, and font number 2 to be 
2 point Times-Roman.  Font 0 is always used as the default font.  You MUST
define at least the font 0 font.

DEFINE_FONT 3 Times-Roman DEFAULT
sets font 3 to be Times-Roman at whatever the default pointsize
is as set by the POINTSIZE command.

DEFINE_FONT 4 Helvetica REL 0.5
sets font 4 to be helvetica at half the default pointsize.

NOTE:  Font names must be written exactly as shown in APPENDIX 3.


SETUP

Signals the end of the STEP 1 commands.

.SH OPTIONAL STEP 1 COMMANDS:

ADD_SEQ <int> <int>
Allows extra sequence positions to be created in an existing alignment.  This
permits additional annotations to be interspaced either above, below, or
anywhere in the middle of an alignment.  For example:
ADD_SEQ 0 10
would create an additional 10 sequences - all set to the blank character
before the first sequence in the block file that has been read in.
ADD_SEQ 3 1
would add an extra sequence after sequence 3.
IMPORTANT: If you use the ADD_SEQ facility to add sequences anywhere except 
after the last sequence, then remember that the sequence
numbers will alter.   All formatting commands that follow this command
must use the new sequence numbering.  Thus in the first example:  
ADD_SEQ 0 10
what was sequence number 1 becomes sequence 11.  Sequences 1-10 are the 
new blank  sequences to be used for annotation.
Note that the sequence numbers only change for commands AFTER the SETUP command,
thus, multiple add_seq commands refer to the sequence number as implied by the
block file.

POINTSIZE <int>

Defines the pointsize to be used to scale the plot and space the characters.
Default is 10 point.

NUMBER_SEQS 

If present, then the sequence number is output with the identifier
code.  This is useful for finding the coordinates of residues to box
or otherwise highlight.

LANDSCAPE

Specifies that alignments will be plotted with the longest paper axis 
horizontal.  (Can get longer alignments on a page this way).

PORTRAIT

Specifies that alignments will be plotted with the longest paper axis vertical
(can get more sequences on a page this way). 

IDENT_WIDTH <int>
Units are characters.

Reserves <int> characters at left of every page for plotting
identifiers.  Note that not all this space need be used, if a smaller
pointsize is used to plot out the identifier codes, than is used for
the main alignment.

LINE_WIDTH_FACTOR <float>

Value greater than 0 that scales the default line width.  The linewidth
is obtained by multiplying the pointsize by this factor.

X_SPACE_FACTOR <float>
Y_SPACE_FACTOR <float>

This determines the spacing between adjacent residues in the X and Y
directions.  The spacing is calculated as: POINTSIZE + POINTSIZE *
X_SPACE_FACTOR or POINTSIZE + POINTSIZE * Y_SPACE_FACTOR as
appropriate.  Defaults are 0.2 and 0.0 respectively.

X_SHIFT_FACTOR <float>
Y_SHIFT_FACTOR <float>

These determine the shift relative to the residue drawing position
that is given to the boxing lines.  The shift is calculated as
follows

(POINTSIZE + POINTSIZE * X_SPACE_FACTOR) *  X_SHIFT_FACTOR
similarly for Y_SHIFT_FACTOR

The defaults are 0.3 and 0.0 respectively.

Fiddling with the X_SPACE/SHIFT values is useful to fine tune the
appearance of the alignment.


MAX_INPUT_LEN <int>

Units are characters.
Defines the maximum number of characters possible in the input line
length.  This must be  greater than the maximum number of sequences
(MAX_NSEQ).

e.g.  MAX_INPUT_LEN 600    

Increases the default value of 500 characters to 600 characters.

MAX_NSEQ <int>

Units are characters.  Defines the maximum number of sequences that
may be read by the program.  This parameter has a large default (500).
You may need to reduce it on computers with small memories.

MAX_ILEN <int>

Units are characters.
The maximum length allowed for a sequence identifier code.

MAX_SEQ_LEN <int>

Defines the maximum length allowed for a sequence alignment - this may
need to be reduced from the 8000 default value on smaller computers.

X_OFFSET <int>
Units of points (1/72 inch).

Defines the offset along the X-axis that the alignments will be shifted prior
to printing.  Fiddle with this value to get a nice offset from the bottom left
hand corner of the page if your page size is not A4.

Y_OFFSET <int>
Units of points (1/72 inch).

As for X_OFFSET, only Y axis.

MAX_SIDE <int>
Units of inches.

Defines the length of the longest side of the printer page.

MIN_SIDE <int>
Units of inches.

Defines the length of the shortest side of the printer page.

VERTICAL_SPACING <int>

Defines the vertical spacing in character units between blocks of sequences
when more than one block will fit on a page - default is 0.


DEFINE_COLOUR <int> <float> <float> <float>
DEFINE_COLOR

Defines a colour - the first number is a number by which the colour will
be referred.  The following three numbers are the intensities of red,
green and blue respectively.  Thus:

DEFINE_COLOUR 1 0 0.2 0.8

sets colour number 1 to be a colour with no red, 0.2 green and 0.8 blue.
The exact appearance of this colour will depend on the output device. 
If you find suitable combinations of colours for your printer, then
please let me know and I shall distribute your suggestions with the
program.

DO_TICKS
If present, then tick marks are drawn below the numbers at the top of the page.
Otherwise no ticks are shown.

NUMBER_INT <int>
Specifies the interval for writing residue position numbers.  Default is 10

NO_NUMBERS
Switches all residue numbering off.



.SH STEP 2 COMMANDS

All these are optional formatting commands.

IMPORTANT PLEASE READ THIS NOTE:

For those commands that accept region definitions (e.g. SURROUND_CHARS) it
is easiest to think of the region being defined in terms of X and Y 
coordinates, where X is the sequence residue coordinate and Y is the 
sequence number coordinate.  Thus 3 7 means the 3rd residue in sequence 7.
3 7 12 42 means the rectangular box bounded by residue 3 of sequence 7 and
residue 12 of sequence 42.  

SURROUND_CHARS <string> ALL

Draw lines round, but not between the characters that are in the string.
e.g.
SURROUND_CHARS GP ALL
will draw lines round all G and P characters in the alignment, but not 
between adjacent G and P characters.

SURROUND_CHARS <string> <int> <int> <int> <int>

Similar command, but the surrounding is restricted to the region defined by 
the four integers.

e.g.

SURROUND_CHARS ILVW 3 12 7 32

would surround ILVW characters that occur in the region defined 
from residue positions 3-7 of sequences 12 to 32.

SHADE_CHARS <string> ALL <float>

Shade all characters in the <string> by the grey value given by <float>.
e.g.
SHADE_CHARS GP ALL 0.5
would shade all G and P characters in the alignment by the grey value 0.5.

SHADE_CHARS  <string> <int> <int> <int> <int> <float>
restricts the shading to the region defined by the four integers.  Thus
SHADE_CHARS ILVW 3 12 7 32 0.7
would shade I L V and W characters from residues 3-7 of sequences 12-32 
inclusive with a grey value of 0.7.

FONT_CHARS <string> ALL <int>

e.g. 
FONT_CHARS GP ALL 7
would use font 7 to write out all G and P characters.  Font 7 MUST have been
defined using the DEFINE_FONT commands above.

FONT_CHARS  <string> <int> <int> <int> <int> <int>
Similar to previous command, but restricts the effect to the region defined
by the first four integers.  The font must have been defined by the 
DEFINE_FONT command. 

e.g.
FONT_CHARS ILVW 3 45 9 70 7

Would set the font to 7 for I L V and W characters for residues 3-9 of
sequences 45-70 inclusive.  The font must have been defined by the
DEFINE_FONT command.

FONT_REGION <int> <int> <int> <int> <int>

Define the font to use throughout the region specified by the first four
integers.

e.g.
FONT_REGION 3 12 20 40 10
Use font 10 for residues from residues 3-20 of sequences 12-40.  The font
must have been defined using the DEFINE_FONT command.

FONT_RESIDUE <int> <int> <int>

Set the font for use with a single residue position - most useful when used
with the TEXT command.

e.g.  
FONT_RESIDUE 3 7 2
Use font 2 for residue 3 of sequence 7.  Font 2 must have been defined using 
the DEFINE_FONT command.

LINE <string> <int> <int> <int>

There are four commands of this type for drawing horizontal or vertical lines
on the alignment.

LINE LEFT <int> <int> <int>

Draw a line to the left of the character positions indicated.
e.g. LINE LEFT 3 12 24
Draw a vertical line starting at residue 3 of sequence 12 and ending at
residue 3 of sequence 24.

LINE TOP 3 12 24  
Draw a horizontal line above the character positions from residue 3 of 
sequence 12 to residue 24 of sequence 12.

Similar commands are:

LINE BOTTOM <int> <int> <int>  Draw a line at bottom of character position.
LINE RIGHT  <int> <int> <int>  Draw a line at right of character position.

BOX_REGION <int> <int> <int> <int>
Draw a box around the region indicated by the four integers.
e.g.
BOX_REGION 2 5 30 7
Would box from residue 2 of sequence 5 to residue 30 of sequence 7.

SHADE_REGION <int> <int> <int> <int> <float>

Shade the region indicated by the integers with the grey value shown by the
float.
e.g.
SHADE_REGION 30 40 35 46 0.2
Would shade from residue 30-35 of sequences 40-46 with a grey value of 0.2.

SHADE_RES <int> <int> <float>
Shade just one amino acid with the grey value.
e.g.
SHADE_RES 3 4 0.7
Shades residue 3 of sequence 7. (Note:  this can also be achieved with the 
SHADE_REGION command, but requires 2 extra numbers)

TEXT <int> <int> <qstring>

Place the text string at the location indicated.
e.g.
TEXT 30 70 "Active Site His"

would put the text Active Site His starting at position 30 of sequence
70.  (Use FONT_RESIDUE or FONT_REGION commands to set the font of the
text).  Text added with the TEXT command will not be split across page
breaks, so you may in some circumstances need to fiddle a little with
the location/pointsize for the text to get the desired result.

ID_FONT ALL <int>
Set the font for all identifier codes to the font number shown by <int>.
e.g.
ID_FONT ALL 3
Would set all the identifier codes to font 3.

ID_FONT <int> <int>
Set the font for a specific identifier to font number.
e.g.
ID_FONT 12 4
Use font 4 for the identifer of sequence 12, default font for all other 
identifiers.

SUB_CHARS ALL <char> <char>

Substitute the characters indicated.
e.g.
SUB_CHARS ALL + *
would change all occurences of + to * in the alignment.

SUB_CHARS <int> <int> <int> <int> <char> <char>
restrict the substitution to the region shown.
e.g.
SUB_CHARS 1 1 7 8 % * 
would substitute * for % from residue 1-7 of sequences 1-8.
NOTE:  To substitute for or with  the space character use the word SPACE.
e.g. to change all space characters to -.
SUB_CHARS ALL SPACE -

SUB_ID <int> <qstring>
Replace the numbered identifier by the string.
e.g.
SUB_ID 34 "Predicted Secondary Structure"
would replace whatever the identifier of sequence 34 was, by the text shown.
This is useful when used in conjunction with the ADD_SEQ command shown under
the STEP 1 commands.

INVERSE_CHARS <string> ALL/Range (similar syntax to FONT_CHARS but no
font number)

Print the selected characters in white.  This clearly will only work
if you first use the SHADE_CHARS command to shade the characters with
something other than white.

CCOL_CHARS <string> ALL <int>

Colour all characters in the <string> by the colour defined by <int>.
e.g.
CCOL_CHARS GP ALL 12
would colour all G and P characters in the alignment by the colour 12.  
This colour MUST have been defined by the DEFINE_COLOUR command.

CCOL_CHARS  <string> <int> <int> <int> <int> <int>
restricts the colouring to the region defined by the four integers.  Thus
CCOL_CHARS ILVW 3 12 7 32 7
would colour I L V and W characters from residues 3-7 of sequences 12-32 
inclusive with the colour 7.

SCOL_CHARS:  This has identical syntax to SCOL_CHARS, but colours the
background of the character, rather than the letter itself. 

COLOUR_REGION  <int> <int> <int> <int> <int>
COLOR_REGION

Colour the region indicated by the integers with the colour number given
as the last number.
e.g.
COLOUR_REGION 30 40 35 46 2
Would colour from residue 30-35 of sequences 40-46 with the colour 2.

COLOUR_RES <int> <int> <int>
Colour just one amino acid with the defined colour.
e.g.
COLOUR_RES 3 4 7
Colours residue 3 of sequence 7. (Note:  this can also be achieved with the 
COLOUR_REGION command, but requires 2 extra numbers)


.SH APPENDIX 2 - AMPS Block file format

The first part of a block-file contains the identifier codes of the 
sequences that are to follow.  Each code is prefixed by the > symbol, codes
must not contain spaces.
e.g.
>HAHU
>Trypsin
>A0046
>Seq1

etc.

ALSCRIPT counts the number of > symbols in the beginning of the file until 
a * symbol is found.  The * signals the beginning of the multiple alignment 
which is stored VERTICALLY, thus columns are individual sequences, whilst
rows are aligned positions.  The * symbol must lie over the first sequence.
A further star in the same column signals the end of the alignment.  ALSCRIPT
uses the number of > symbols at the beginning of the file to work out how 
many columns to read from the * position.  It is therefore important that the
only > symbols in the file are those that define the identifiers, and the only
* symbols are those defining the start and end of the multiple alinnment.

A simple, small block-file is shown here.

>Seq_1
>A0231
>HAHU
>Four_Alpha
>Globin
>GLobin_C
*
ARNDLQ
AAAAAA
PPPPPP
PP PPP
WW WWW
LLLLLL
IIVVLL
*


.SH APPENDIX 3 - PostScript Fonts.

Times-Roman,   
Times-Italic,  
Times-Bold,  
Times-BoldItalic,
Helvetica,  
Helvetica-Oblique,  
Helvetica-Bold,   
Helvetica-BoldOblique,    
Courier,    
Courier-Oblique,    
Courier-Bold
Courier-BoldOblique,      
AvantGarde-Book,       
AvantGarde-BookOblique,     
AvantGarde-Demi,    
AvantGarde-DemiOblique,
Bookman-Demi,  
Bookman-DemiItalic,  
Bookman-Light,  
Bookman-LightItalic,     
Helvetica-Narrow,    
Helvetica-Narrow-Bold,
Helvetica-Narrow-BoldOblique,      
Helvetica-Narrow-Oblique,
NewCenturySchblk-Roman,               
NewCenturySchlbk-Bold,
NewCenturySchblk-Italic,        
NewCenturySchblk-BoldItalic,
Palatino-Roman,  
Palatino-Bold,  
Palatino-Italic,  
Palatino-BoldItalic 
ZapfChancery-MediumItalic.
Symbol

.SH EXAMPLES
Ways of running alscript:

1.  Interactive mode:  just type alscript.
    You will be prompted for a command file name.  The command file will
    define the AMPS blocfile, and name of the file to store the PostScript
    output - see alscript.doc for details.
    
2.  alscript <command_file> has same effect as 1, But does not prompt for 
    the command file
    e.g.  alscript example1.com

3.  alscript -q < <blocfile> > <PostScript>
    Quick mode - uses default commands, reads alignment from stdin, 
    writes PostScript  to stdout.  This mode creates a command file 
    called ALPSQ.COM.

    e.g. alscript -q < example1.blc > example1.ps
    
4.  alscript -f <command_file>
    Similar effect to 2.

5.  alscript -f <command_file> -s
    Silent operation:  No messages are written to stderr, unless fatal.
    Silent operation may be toggled by the silent_mode command 
    in the command file.

6.  alscript -f <command_file> -p < <blocfile> > <PostScript>
    Make alscript work like a pipe - blocfile is read from stdin, 
    postscript is written
    to stdout.  Messages are written to stderr.  To supress messages include
    the -s flag too
    e.g. alscript -f example1.com -p -s < example1.blc > example1.ps

Using alscript as a pipe has the advantage of allowing the blocfile to
be created on the fly by the programs msf2blc or clus2blc.  For example
if we have a GCG .msf file called "pileup.msf" we can run alscript with
default shading/fonts and send the results straight to the PostScript
printer "lpr" as follows:

msf2blc -q < pileup.msf | alscript -q -s | lpr

.SH APPENDIX 8 - Program Crashes and Known Bugs

We've used ALSCRIPT on Sun Workstations for some time,  with very large
alignments and command files with thousands of commands.  All seems to
work OK, the program has not crashed on us at all!!

However, the command interpreter in ALSCRIPT is very simple and
the program will crash if you give any command the wrong number of 
arguments (e.g. leaving out the shade value in a shade_chars command).

Also, the program will crash if you give it out of range sequence numbers.
e.g. refer to sequence 38 when there are only 20 sequences in the block
file.

I hope to include error checking for both these problems in a later 
release of the program.

If you do make the program crash, have checked all the documentation 
and your numbers, and the program still crashes.  Then send me 
the command file and block file that causes the crash and I will try
to investigate.  

Suggestions for improvements to the program are always welcome.

.SH APPENDIX 9 - Plans for next version!

Command interpreter:  An error checking command interpreter will be used.

Position numbering:  Currently, all positions must be referred to in 
the global coordinate system of the alignment.  This is a bit 
annoying  if all your data refer to a specific sequence.  I plan
to allow residue position numbers to be referred to relative to a 
specific sequence, or sequences.  Similarly, the sequence numbering
will be changed to allow a  unique numbering scheme that does not change
when you insert additional lines in the middle of the alignment.

Command aliasing:  This will allow frequently used commands to be 
renamed to something shorter simplify typing!

Note:  In version 1.4.5  part of the position numbering problem is overcome
through the use of the program alsnum.  See "New features of 1.4.5".

.SH APPENDIX10 - References

1.  Barton, G. J. (1993), 
	"ALSCRIPT A tool to format multiple sequence alignments",
	Protein Engineering,  Volume 6, No. 1, pp.37-40.

2.  Barton, G. J. (1990),
    	"Protein Multiple Sequence Alignment and Flexible Pattern Matching",
	Methods in Enzymology,
    	183,403-428.

3.  Barton, G. J. and Sternberg, M. J. E. (1987),
    	"A Strategy for the Rapid Multiple Alignment of Protein Sequences: 
         Confidence Levels From Tertiary Structure Comparisons",
	Journal of Molecular Biology,
    	198,327-337

4. Higgins, D. G. and Sharp, P. M. (1989),
    	"Fast and sensitive multiple sequence alignments on a microcomputer",
	CABIOS,
    	5,151--153

5. Devereux, J. Haeberli, P. Smithies, O. (1984),
    	"A comprehensive set of sequence analysis programs for the VAX",
	Nucleic Acids Res.
    	12, 387-395

6. Livingstone, C.D. and Barton, G. J. (1993),
        (submitted).

.SH AUTHOR
.nf
  Copyright:  University of Oxford (1992,1993)

   Author:  Geoffrey J. Barton
   Laboratory of Molecular Biophysics
   The Rex Richards Building
   South Parks Road
   Oxford OX1 3QU
   UK

   Tel: (+44) 865 275368
   Fax: (+44) 865 510454

   gjb@bioch.ox.ac.uk
.fi

.SH REFERENCE
   Barton, G. J. (1993)
   ALSCRIPT a tool to format multiple sequence alignments
   Protein Engineering, Volume 6, No. 1, pp.37-40.

.SH Related Programs

The AMPS package (Barton, 1990).  This performs multiple sequence
alignments and databank scanning.  The package is currently only
available for Sun, Silicon Graphics and VAX/VMS systems.  Contact the
author for details.

AMAS (Livingstone and Barton, 1993 - submitted).  Analysis of
Multiply Aligned Sequences.  This package uses a sophisticated
set-based method to identify patterns of residue conservation in
multiple sequence alignments.  We hope to distribute these programs
which can be used in conjunction with ALSCRIPT, early in 1993.

