/***************************************************************************

pretty2blc:  A program to convert a GCG .pretty file into an AMPS blockfile.

****************************************************************************/

#include <stdio.h>
#include <stdarg.h>
#include <stdlib.h>
#include <string.h>

#include "gjutil.h"
#include "array.h"
#include "defaults.h"

/* ++pac */
#ifdef _PLAN9
#include "AllMax.h"
#endif


#define TOKENS "{} \t\n\0"


main(int argc, char *argv[])
{
	int pretty = 0, consensus = 0;
	struct seqdat *seqs;
	FILE *fp, *fout;
	int nseq;
	int found;
	int i,j;
        char *token,*sbit;
        char *line, *line_buf, *line_ptr = NULL;
        extern FILE *std_err,*std_in,*std_out;
	char *prettyfile;
	char *blocfile;

	int quiet;

	std_err = stderr;
        std_in = stdin;
        std_out = stdout;

        line = GJstrcreate(MAX_INLEN," ");
	line_buf = GJstrcreate(MAX_INLEN," ");
	prettyfile = GJstrcreate(MAX_INLEN,NULL);
        blocfile = GJstrcreate(MAX_INLEN,NULL);


        nseq = 0;
        found = 0;
	quiet = 0;

	if( argc > 1){
	  if(strcmp(argv[1],"-q")==0){
/* Quiet mode - read .MSF file from stdin and output block file to stdout */
		quiet = 1;
		fp = std_in;
		fout = std_out;
          }
	  if(argc == 4)
          {
            strcpy(prettyfile,argv[2]);
            strcpy(blocfile,argv[3]);
            fp = GJfopen(prettyfile,"r",1);
            fout = GJfopen(blocfile,"w",1);
          }
        }else{
          /* Verbose mode - prompt for all filenames */
          fprintf(std_out,"\n\n");
          fprintf(std_out,"GCG .PRETTY to AMPS Blockfile conversion\n");
          fprintf(std_out,"Copyright: ANGIS (1993)\n");
          fprintf(std_out,"Author: CHuynh (1993)\n\n");
          fprintf(std_out,"Enter PRETTY filename: ");

          fscanf(std_in,"%s",prettyfile);
          fprintf(std_out,"Opening: %s\n",prettyfile);
          fp = GJfopen(prettyfile,"r",1);

          fprintf(std_out,"Enter Block filename: ");
          fscanf(std_in,"%s",blocfile);
          fprintf(std_out,"Opening: %s\n",blocfile);
          fout = GJfopen(blocfile,"w",1);
        }

        fprintf(fout,"\n");
        fprintf(fout,"Conversion of GCG .PRETTY file to AMPS BLOCKFILE format\n");

        seqs = (struct seqdat *) GJmalloc(sizeof(struct seqdat));

   if(!quiet)fprintf(std_out,"Reading .blc file\n");

   pretty = 0;

   while((pretty != 1) && (fgets(line,MAX_INLEN,fp) != NULL))
   {
      if(line[0] != '\n')
      {
          if(strstr( line, "PRETTY of:" ) != NULL )
          {
              pretty = 1;
          }
      }
   }
   if( pretty != 1 )
   {
	fprintf(std_err,"wrong file format\n");
	exit(1);
   }

   pretty = 0;

   while(fgets(line,MAX_INLEN,fp) != NULL)
   {
	if(line[0] != '\n')
	{
	  if( ( line_ptr = strstr(line,"Consensus") ) != NULL )
	  {
		strcpy(line_buf, line_ptr + 8);
		token = strtok(line_ptr,TOKENS);
		consensus = 1;
		goto consense;
	  }
          else if( (line_ptr = strchr(line,'{')) != NULL)
	  {
                 /* This is a seq id name */
	     consensus = 0;
	     strcpy( line_buf, line_ptr + 1 );
             token = strtok(line_ptr,TOKENS);
consense :
             seqs = (struct seqdat *) GJrealloc(seqs,sizeof(struct seqdat) * (nseq +1));
             seqs[nseq].id = GJstrdup(token);
             seqs[nseq].title = NULL;
             seqs[nseq].slen = 0;
             seqs[nseq].seq = (char *) GJmalloc(sizeof(char));
	     if( (nseq != 0) && (strcmp(token,seqs[0].id) == 0) )
		pretty = 1;
	     if( pretty == 0 )
                ++nseq;
	     if(!quiet)fprintf(std_out,"%s\n",seqs[nseq-1].id);

             /* read in the sequence */
             i=0;
             for(i=0;i<nseq;++i)
                if(strcmp(token,seqs[i].id) == 0)
                   break;
             /* read in the sequence */
             if(i < nseq)
             {
		if(consensus != 1)
		   line_ptr = strchr(line_buf, '}');
		else
	 	   line_ptr = line_buf;
		line_ptr = line_ptr + 3;

                j=0;
                while(line_ptr[j] != '\0')
	        {
                  if(isalpha(line_ptr[j]) || (line_ptr[j] == '.') ||
			(line_ptr[j] == '-') )
		  {
                     seqs[i].seq = (char *) GJrealloc(seqs[i].seq,sizeof(char) * (seqs[i].slen +1));
                     seqs[i].seq[seqs[i].slen] = line_ptr[j];
                     ++seqs[i].slen;
		  }
		  seqs[i].seq[seqs[i].slen] = '\0';
                  ++j;
		}	/* while line_ptr[j] */
	     }	/* if (i < nseq) */
	  }	/* else if */
	  else
		fprintf(fout,"%s\n",line);

	}	/* line[0] */
   }	/* fgets */

/* Start writing  seqs into blocfile */

        if(!quiet)fprintf(std_out,"All %d sequences read in\n",nseq);
        if(!quiet)fprintf(std_out,"Writing .blc file\n");

        for(i=0;i<nseq;++i){
            fprintf(fout,">%s\n",seqs[i].id);
        }
        fprintf(fout,"* iteration 1\n");
        for(i=0;i<seqs[0].slen;++i){
            for(j=0;j<nseq;++j){
                fprintf(fout,"%c",seqs[j].seq[i]);
            }
            fprintf(fout,"\n");
        }

        fprintf(fout,"*\n");
        if(!quiet)fprintf(std_out,"All done\n");

        for(i=0;i<nseq;++i){
          GJfree(seqs[i].seq);
          GJfree(seqs[i].id);
        }
        GJfree(seqs);
        GJfree(line);
	GJfree(line_buf);
        GJfree(blocfile);
        GJfree(prettyfile);

}

